pub enum DurableEventQueueError {
EventQueue(EventQueueError),
RocksDb(Error),
PoisonedLock,
Serialize {
source: Error,
},
Deserialize {
id: u64,
source: Error,
},
InvalidKeyLength {
actual: usize,
},
IdOverflow,
UnknownEvent {
id: u64,
},
}Expand description
Error returned by durable queue operations.
Variants
EventQueue(EventQueueError)
Error from the in-memory ready queue.
RocksDb(Error)
Error returned by RocksDB.
PoisonedLock
An internal durable queue lock was poisoned by a panicking thread.
Serialize
Failed to serialize an event payload before writing it to RocksDB.
Deserialize
Failed to deserialize a persisted event payload.
InvalidKeyLength
Found a RocksDB key that is not a valid durable event id.
IdOverflow
The queue cannot assign another event id.
UnknownEvent
The requested event id is not present in the durable store.