pub enum EventQueueError {
PoisonedLock,
PoisonedCondvar,
}Expand description
Error returned by in-memory queue operations.
Variants
PoisonedLock
The queue mutex was poisoned by a panicking thread.
PoisonedCondvar
The queue condition variable wait returned with a poisoned lock.